# sphinx-autodoc-toolbox

Extensions for sphinx autodoc

- GitHub: https://github.com/haiiliin/sphinx-autodoc-toolbox/
- Documentation: https://sphinx-autodoc-toolbox.readthedocs.io/en/latest/
- PyPI: https://pypi.org/project/sphinx-autodoc-toolbox/
- Read the Docs: https://readthedocs.org/projects/sphinx-autodoc-toolbox/
